@@ -1,6 +1,8 @@
-from django.test import TestCase
-from django.contrib.auth import get_user_model
+from __future__ import unicode_literals
 
+from django.test import TestCase
+
+from ..compat import get_user_model
 from ..models import AccessToken, Application
 
 
